@@ -11,7 +11,7 @@
 
 #include <complex>
 
-#include "gtest/gtest.h"
+#include "test_common_macros.hpp"
 
 namespace xtl
 {
